Trait sorted_iter::sorted_iterator::SortedByItem
source · pub trait SortedByItem { }Expand description
marker trait for iterators that are sorted by their Item
pub trait SortedByItem { }marker trait for iterators that are sorted by their Item